BOOST_PP_LIST_TO_SEQ

The BOOST_PP_LIST_TO_SEQ macro converts a list to a seq.

#### Usage

BOOST_PP_LIST_TO_SEQ(list)

#### Arguments

list
  The list to be converted.

#### Remarks

This macro uses BOOST_PP_FOR. Within BOOST_PP_FOR, it is more efficient to use BOOST_PP_LIST_TO_SEQ_R.

#### See Also

- BOOST_PP_LIST_TO_SEQ_R

#### Requirements

Header: <boost/preprocessor/list/to_seq.hpp>

#### Sample Code

    #include <boost/preprocessor/list/to_seq.hpp>

    BOOST_PP_LIST_TO_SEQ((a, (b, (c, BOOST_PP_NIL)))) // expands to (a)(b)(c)

© Copyright Edward Diener 2011

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)